@@ -56,9 +56,6 @@ namespace FSpot {
 				if (adaptor is TimeAdaptor) {
 					MainWindow.ToolTips.SetTip (left, Catalog.GetString ("More dates"), null);
 					MainWindow.ToolTips.SetTip (right, Catalog.GetString ("More dates"), null);
-				} else if (adaptor is DirectoryAdaptor) {
-					MainWindow.ToolTips.SetTip (left, Catalog.GetString ("More directories"), null);
-					MainWindow.ToolTips.SetTip (right, Catalog.GetString ("More directories"), null);
 				} else {
 					MainWindow.ToolTips.SetTip (left, Catalog.GetString ("More"), null);
 					MainWindow.ToolTips.SetTip (right, Catalog.GetString ("More"), null);
@@ -337,6 +334,9 @@ namespace FSpot {
 			//Rectangle box = glass.Bounds ();
 			//Console.WriteLine ("please {0} and {1} in box {2}", x, y, box);
 
+			if (glass == null)
+				return base.OnMotionNotifyEvent (args);
+
 			if (glass.Dragging) {
 				glass.UpdateDrag (x, y);
 			} else if (min_limit.Dragging) {
@@ -512,23 +512,10 @@ namespace FSpot {
 		{
 			Gtk.Menu order_menu = new Gtk.Menu();
 			
-			GtkUtil.MakeCheckMenuItem (order_menu, Catalog.GetString ("Arrange by _Month"),
-					      MainWindow.Toplevel.HandleArrangeByTime, true, (adaptor is TimeAdaptor), true);
-			
-			GtkUtil.MakeCheckMenuItem (order_menu, Catalog.GetString ("Arrange by _Folder"),
-					      MainWindow.Toplevel.HandleArrangeByDirectory, true, (adaptor is DirectoryAdaptor), true);
+			order_menu.Append (MainWindow.Toplevel.ReverseOrderAction.CreateMenuItem ());
 
-			GtkUtil.MakeMenuSeparator (order_menu);
-
-			GtkUtil.MakeCheckMenuItem (order_menu, Catalog.GetString ("_Reverse Order"),
-					      MainWindow.Toplevel.HandleReverseOrder, true, adaptor.OrderAscending, false);
-
-			if (adaptor is TimeAdaptor && adaptor.Query.Range != null) {
-				GtkUtil.MakeMenuSeparator (order_menu);
-
-				GtkUtil.MakeMenuItem (order_menu, Catalog.GetString ("_Clear Date Range"), 
+			GtkUtil.MakeMenuItem (order_menu, Catalog.GetString ("_Clear Date Range"), 
 						MainWindow.Toplevel.HandleClearDateRange);
-			}
 			
 			if (args != null)
 				order_menu.Popup (null, null, null, args.Button, args.Time);
@@ -910,6 +897,14 @@ namespace FSpot {
 			if (event_window != null)
 				event_window.Show ();
 		}
+
+		protected override void OnUnmapped ()
+		{
+			base.OnUnmapped ();
+			if (event_window != null)
+				event_window.Hide ();
+			
+		}
 		
 		protected override bool OnExposeEvent (Gdk.EventExpose args)
 		{
@@ -923,9 +918,8 @@ namespace FSpot {
 					active.X = min_x;
 					active.Width = max_x - min_x;
 					
-					if (active.Intersect (area, out active)) {
+					if (active.Intersect (area, out active))
 						GdkWindow.DrawRectangle (Style.BaseGC (State), true, active);
-					}
 					
 					int i;
 					BoxXHit (area.X, out i);
@@ -965,9 +959,10 @@ namespace FSpot {
 			
 		protected override void OnSizeRequested (ref Requisition requisition)
 		{
+			left.SizeRequest ();
+			right.SizeRequest ();
 			requisition.Width = 500;
 			requisition.Height = (int) (LegendHeight () + glass.handle_height + 3 * border);
-			base.OnSizeRequested (ref requisition);
 		}
 
 		// FIXME I can't find a c# wrapper for the C PANGO_PIXELS () macro
